import java.awt.*;

public class DrawingBattleship {
    public EntityBattleship entityBattleship;
    private DrawingBlocks drawingBlocks;
    private int pictureWidth;
    private int pictureHeight;
    private int startPosX;
    private int startPosY;
    private final int shipWidth = 175;
    private final int shipHeight = 80;

    public boolean Init(int speed, double weight, Color bodyColor, Color
            additionalColor, boolean turret, boolean rocketLauncher, int width, int height, int blocksNumber) {
        if (width < shipWidth || height < shipHeight)
            return false;
        pictureWidth = width;
        pictureHeight = height;
        entityBattleship = new EntityBattleship();
        entityBattleship.Init(speed, weight, bodyColor, additionalColor, turret, rocketLauncher);
        drawingBlocks = new DrawingBlocks();
        drawingBlocks.setNumber(blocksNumber);
        return true;
    }
    public void SetPosition(int x, int y) {
        if (x < 0 || y < 0 || x + shipWidth > pictureWidth || y + shipHeight > pictureHeight) {
            x = 0;
            y = 0;
        }
        startPosX = x;
        startPosY = y;
    }
    public void moveTransport(DirectionType direction) {
        if (entityBattleship == null)
            return;
        switch (direction) {
            //влево
            case LEFT:
                if (startPosX - entityBattleship.Step > 0) {
                    startPosX -= entityBattleship.Step;
                }
                break;
            case UP:
                if (startPosY - entityBattleship.Step > 0) {
                    startPosY -= entityBattleship.Step;
                }
                break;
            case RIGHT:
                if (startPosX + shipWidth + entityBattleship.Step < pictureWidth) {
                    startPosX += entityBattleship.Step;
                }
                break;
            case DOWN:
                if (startPosY + shipHeight + entityBattleship.Step < pictureHeight) {
                    startPosY += entityBattleship.Step;
                }
                break;
            default:
                break;
        }
    }

    public void drawTransport(Graphics2D g2d){
        if(entityBattleship == null)
            return;
        BasicStroke pen = new BasicStroke(2);
        g2d.setStroke(pen);
        Color bodyColor = entityBattleship.BodyColor;
        Color additionalColor = entityBattleship.AdditionalColor;
    //основа
        int[] xPoints = {startPosX + 5, startPosX + 120, startPosX + 160, startPosX + 120, startPosX + 5};
        int[] yPoints = {startPosY + 0, startPosY + 0, startPosY + 35, startPosY + 70, startPosY + 70};
        g2d.setColor(bodyColor);
        g2d.fillPolygon(xPoints, yPoints, 5);
        g2d.setPaint(Color.BLACK);
        g2d.drawPolygon(xPoints, yPoints, 5);

    //блоки

        g2d.setPaint(Color.DARK_GRAY);
        g2d.fillRect(startPosX + 70, startPosY + 15, 20, 40);
        g2d.setPaint(Color.BLACK);
        g2d.drawRect(startPosX + 70, startPosY + 15, 20, 40);
        g2d.setPaint(Color.DARK_GRAY);
        g2d.fillRect(startPosX + 40, startPosY + 25, 30, 20);
        g2d.setPaint(Color.BLACK);
        g2d.drawRect(startPosX + 40, startPosY + 25, 30, 20);
        g2d.setPaint(Color.DARK_GRAY);
        g2d.fillOval(startPosX + 100, startPosY + 20, 30, 30);
        g2d.setPaint(Color.BLACK);
        g2d.drawOval(startPosX + 100, startPosY + 20, 30, 30);

    //для ускорения
        g2d.setPaint(Color.YELLOW);
        g2d.fillRect(startPosX + 0, startPosY + 10, 5, 20);
        g2d.fillRect(startPosX + 0, startPosY + 40, 5, 20);
        g2d.setPaint(Color.BLACK);
        g2d.drawRect(startPosX + 0, startPosY + 40, 5, 20);
        g2d.drawRect(startPosX + 0, startPosY + 10, 5, 20);

        //блоки
        if (drawingBlocks != null) {
            drawingBlocks.drawBlocks(g2d, startPosX, startPosY);
        }
        //орудийная башня
        if (entityBattleship.Tower) {
            g2d.setColor(additionalColor);
            g2d.fillRect(startPosX + 108, startPosY + 28, 15, 15);
            g2d.drawRect(startPosX + 108, startPosY + 28, 15, 15);
           // добавить черный цвет пушке
            Color gunColor = Color.BLACK;
            g2d.setColor(gunColor);
            g2d.setStroke(pen);
            g2d.fillRect(startPosX + 123, startPosY + 32, 47, 6);
            g2d.drawRect(startPosX + 123, startPosY + 32, 55, 6);
        }
        //отсеки под ракеты
        if (entityBattleship.Section) {
            //добавить серый цвет
            g2d.setColor(additionalColor);
            g2d.fillRect(startPosX + 20, startPosY + 70, 40, 10);
            g2d.fillRect(startPosX + 75, startPosY + 70, 40, 10);
            g2d.setPaint(Color.BLACK);
            g2d.drawRect(startPosX + 20, startPosY + 70, 40, 10);
            g2d.drawRect(startPosX + 75, startPosY + 70, 40, 10);
        }

    }

}
